Cache

Struct Cache 

pub struct Cache<A: AtomicArcRef> { /* private fields */ }
A cache for a shared AtomicArc.

Built as a wrapper around AtomicArc::load_cached, it essentially makes loads of up-to-date Arcs free, but requires a mutable reference.

As the cache stores the latest loaded Arc, it can delay its reclamation until a new Arc is loaded.

Examples

let atomic_arc = Arc::new(AtomicArc::<usize>::from(0));
let mut cache = hazarc::Cache::new(atomic_arc);
assert_eq!(**cache.load(), 0);

It also works with AtomicOptionArc.

let atomic_arc = Arc::new(AtomicOptionArc::<usize>::none());
let mut cache = hazarc::Cache::new(atomic_arc);
assert_eq!(cache.load(), None);

Implementations

Source

impl<A: AtomicArcRef> Cache<A>

pub fn new(inner: A) -> Self

Constructs a new Cache, loading and storing the up-to-date Arc.

pub fn inner(&self) -> &A

Accesses the inner shared AtomicArc.

pub fn into_inner(self) -> A

Consumes the cache to returns the inner shared AtomicArc.

pub fn load(&mut self) -> A::LoadCached<'_>

Returns a reference the cached Arc, updating it when it is outdated.

pub fn load_shared(&self) -> A::LoadCachedOrReload<'_>

Returns a reference to the cached Arc if it is up-to-date, or loads the latest Arc.

Contrary to load, it doesn’t require a mutable reference; as a consequence, the cached Arc is not updated when the latest Arc is loaded.

This method is intended for workflows where the atomic Arc is unlikely to be updated after the cache construction.